Structs
- Maintenance
Task Policy - Policy for one post-turn maintenance task.
- Post
Turn Optimization Config - Post-turn task policies for work that affects later turns.
- Runtime
Config - Runtime-level configuration for latency optimization and tool prompt behavior.
- Runtime
Optimization Config - Controls safe pre-response routing, maintenance concurrency, and runtime task limits.
Enums
- Await
Before Next Turn - Freshness policy for pending background maintenance.
- Background
Overflow Policy - Behavior when a background queue cannot accept more tasks.
- Maintenance
Mode - Execution mode for post-turn maintenance.
- Streaming
Optimization Policy - Streaming behavior when optimized routing may run before output begins.