Module maintenance

Module maintenance 

Structs

BackgroundMaintenanceQueue
Bounded queue for post-turn maintenance that can be flushed by eval and shutdown paths.
MaintenanceSequenceKey
Sequence key used to preserve order for actor or session scoped maintenance.

Enums

RuntimeTaskPurpose
Runtime work categories used for optimization and background ordering.