Module streaming

Module streaming 

Structs

StreamBranchBuffer
Bounded buffer used while streaming output waits for routing to resolve.
StreamingDraftResult
Fully buffered stream branch output before the branch commits.