pub struct RouterRolesConfig {Show 14 fields
pub default: Option<String>,
pub state: Option<StateRouterConfig>,
pub skills: Option<SkillsRouterConfig>,
pub tools: Option<ToolsRouterConfig>,
pub process: Option<ProcessRouterConfig>,
pub disambiguation: Option<DisambiguationRouterConfig>,
pub reasoning: Option<ReasoningRouterConfig>,
pub memory: Option<MemoryRouterConfig>,
pub context: Option<ContextRouterConfig>,
pub orchestration: Option<OrchestrationRouterConfig>,
pub hitl: Option<HitlRouterConfig>,
pub spawner: Option<SpawnerRouterConfig>,
pub web: Option<WebRouterConfig>,
pub evaluation: Option<EvaluationRouterConfig>,
}Expand description
Agent-local hierarchy of literal registry aliases.
Fields
default: Option<String>state: Option<StateRouterConfig>skills: Option<SkillsRouterConfig>tools: Option<ToolsRouterConfig>process: Option<ProcessRouterConfig>disambiguation: Option<DisambiguationRouterConfig>reasoning: Option<ReasoningRouterConfig>memory: Option<MemoryRouterConfig>context: Option<ContextRouterConfig>orchestration: Option<OrchestrationRouterConfig>hitl: Option<HitlRouterConfig>spawner: Option<SpawnerRouterConfig>web: Option<WebRouterConfig>evaluation: Option<EvaluationRouterConfig>Implementations
Sourceimpl RouterRolesConfig
impl RouterRolesConfig
Sourcepub fn select<'a>(
&'a self,
role: LLMRole,
local: Option<&'a str>,
main: &'a str,
) -> (&'a str, LLMSelectionSource)
pub fn select<'a>( &'a self, role: LLMRole, local: Option<&'a str>, main: &'a str, ) -> (&'a str, LLMSelectionSource)
Selects an alias without retrying missing registrations or provider failures.
Sourcepub fn configured_aliases(&self) -> Vec<(&'static str, &str)>
pub fn configured_aliases(&self) -> Vec<(&'static str, &str)>
Lists only explicit tree aliases, including inactive roles, for preflight.