pub struct BackgroundMaintenanceQueue { /* private fields */ }Expand description
Bounded queue for post-turn maintenance that can be flushed by eval and shutdown paths.
Implementations
Sourceimpl BackgroundMaintenanceQueue
impl BackgroundMaintenanceQueue
Sourcepub fn spawn<F>(
&self,
key: Option<MaintenanceSequenceKey>,
future: F,
) -> Result<()>
pub fn spawn<F>( &self, key: Option<MaintenanceSequenceKey>, future: F, ) -> Result<()>
Spawns a background task and applies per-key ordering when a key is supplied.
Sourcepub async fn flush_all(&self) -> Result<()>
pub async fn flush_all(&self) -> Result<()>
Waits for all tracked background tasks to complete.
Sourcepub async fn flush_scope(&self, scope_id: &str) -> Result<()>
pub async fn flush_scope(&self, scope_id: &str) -> Result<()>
Waits for tasks with the requested scope identifier and keeps unrelated work queued.
Sourcepub async fn flush_purpose(&self, purpose: RuntimeTaskPurpose) -> Result<()>
pub async fn flush_purpose(&self, purpose: RuntimeTaskPurpose) -> Result<()>
Waits for tasks with the requested purpose and keeps unrelated work queued.
Sourcepub async fn flush_scope_purpose(
&self,
scope_id: &str,
purpose: RuntimeTaskPurpose,
) -> Result<()>
pub async fn flush_scope_purpose( &self, scope_id: &str, purpose: RuntimeTaskPurpose, ) -> Result<()>
Waits for tasks with the requested scope and purpose.